pygeodesy.triaxials.conformal3.Conformal3B

Package pygeodesy :: Package triaxials :: Module conformal3 :: Class Conformal3B |
[frames] | no frames]

# Class Conformal3B

          object --+
                   |
        named._Named --+
                       |
        named._NamedBase --+
                           |
        named._NamedEnumItem --+
                               |
    bases._UnOrderedTriaxialBase --+
                                   |
          bases._OrderedTriaxialBase --+
                                       |
                    bases._Triaxial3Base --+
                                           |
                                  Conformal3 --+
                                               |
                                              Conformal3B

Jacobi Conformal projection on a triaxial ellipsoid specified by its middle semi-axis and shape.

See Also: Conformal3 for details and more information.

Instance Methods
__init__(self, b, e2=0.0, k2=1.0, kp2=0.0, **name) New Conformal3B triaxial. |
Inherited from `Conformal3`: `equi3Sphere`, `forwardBetOmg`, `forwardOther`, `forwardSphere3`, `reverseBetOmg`, `reverseOther`, `reverseSphere` Inherited from `bases._UnOrderedTriaxialBase`: `__repr__`, `areaKT`, `area_p`, `ellipse5`, `hartzell4`, `height4`, `normal3d`, `normal4`, `sideOf`, `toBiaxial`, `toEllipsoid`, `toStr` Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `Conformal3`: `xyQ2` Inherited from `bases._Triaxial3Base`: `Lon0`, `e2`, `isBiaxial`, `isOblate`, `isProlate`, `k2`, `kp2` Inherited from `bases._OrderedTriaxialBase`: `area`, `area21k` Inherited from `bases._UnOrderedTriaxialBase`: `R2`, `R3`, `Rauthalic`, `Rvolumetric`, `a`, `a2`, `abc3`, `areaRG`, `b`, `b2`, `c`, `c2`, `e2ab`, `e2ac`, `e2bc`, `isFlat`, `isOrdered`, `isSpherical`, `perimeter4ab`, `perimeter4ac`, `perimeter4bc`, `unOrdered`, `volume` Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, b, e2=0.0, k2=1.0, kp2=0.0, **name) (Constructor) |
New Conformal3B triaxial. Arguments: `a_triaxial` - Largest semi-axis (`scalar`, conventionally in `meter`) or an other Triaxial or Triaxial_ instance. `b` - Middle semi-axis (`meter`, same units as `a`), required if `a_triaxial is scalar`, ignored otherwise. `c` - Smallest semi-axis (`meter`, like `b`). `name` - Optional `name=NN` (`str`). Raises: `TriaxialError` - Semi-axes unordered, spherical or invalid. Overrides: object.__init__ Note: Use `b=radius` and `e2=0` for a conformal spherical projection. See Also: Conformal.